Cancel class

Constructors

Cancel({GestureTapCallback? cancelClicked, AssetImage? cancelImage, double cancelImageSize = 15.0, Color? cancelImageColor, bool autoHidden = true})

Properties

autoHidden → bool
Whether to automatically hide the cancel button when progress completes. When true, the button will be hidden when progress value equals max value. Defaults to true.
final
cancelClicked → GestureTapCallback?
Callback function that will be executed when cancel button is tapped.
final
cancelImage → AssetImage?
Custom image to use for the cancel button. If not provided, uses default cancel icon.
final
cancelImageColor → Color?
Color to apply to the cancel button image.
final
cancelImageSize → double
Size of the cancel button image in pixels. Defaults to 15.0.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited