Completed class

Constructors

Completed({Future<String>? completedMsgFuture, String completedMsg = "Completed !", int completionDelay = 1500, AssetImage? completedImage})

Properties

completedImage → AssetImage?
Custom image to display when progress completes. If not provided, uses default completion icon.
final
completedMsg → String
Message to display when progress completes. Defaults to "Completed !".
final
completedMsgFuture → Future<String>?
Future that resolves to the completion message. If provided, this message will override completedMsg when resolved.
final
completionDelay → int
Duration to wait before closing the dialog after completion, in milliseconds. Defaults to 1500ms.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited